@@ -216,10 +216,9 @@ class DiagramNode(Element):
         self.linecolor = images.color_to_rgb(color)
 
     def set_shape(self, value):
-        try:
-            noderenderer.get(value)
+        if noderenderer.get(value):
             self.shape = value
-        except:
+        else:
             msg = "WARNING: unknown node shape: %s\n" % value
             raise AttributeError(msg)
 
@@ -308,6 +307,19 @@ class NodeGroup(Element):
             else:
                 yield node
 
+    def traverse_edges(self, preorder=False):
+        if preorder:
+            for edge in self.edges:
+                yield edge
+
+        for group in self.traverse_groups(preorder):
+            for edge in group.traverse_edges(preorder):
+                yield edge
+
+        if not preorder:
+            for edge in self.edges:
+                yield edge
+
     def traverse_groups(self, preorder=False):
         for node in self.traverse_nodes(preorder=preorder):
             if isinstance(node, NodeGroup):
@@ -438,6 +450,7 @@ class DiagramEdge(Base):
         self.skipped = 0
 
         self.label = None
+        self.description = None
         self.dir = 'forward'
         self.color = self.basecolor
         self.hstyle = None
@@ -458,17 +471,17 @@ class DiagramEdge(Base):
 
     def set_dir(self, value):
         value = value.lower()
-        if value in ('back', 'both', 'none', 'forward',
-                     'onemany', 'manyone', 'manymany'):
+        if value in ('back', 'both', 'none', 'forward'):
             self.dir = value
-        elif value == 'oneone':
-            self.dir = 'none'
         elif value == '-<':
-            self.dir = 'onemany'
+            self.dir = 'forward'
+            self.hstyle = 'onemany'
         elif value == '>-':
-            self.dir = 'manyone'
+            self.dir = 'back'
+            self.hstyle = 'manyone'
         elif value == '>-<':
-            self.dir = 'manymany'
+            self.dir = 'both'
+            self.hstyle = 'manymany'
         elif value == '->':
             self.dir = 'forward'
         elif value == '<-':
@@ -488,6 +501,18 @@ class DiagramEdge(Base):
         value = value.lower()
         if value in ('generalization', 'composition', 'aggregation'):
             self.hstyle = value
+        elif value == 'oneone':
+            self.dir = 'none'
+            self.hstyle = value
+        elif value == 'onemany':
+            self.dir = 'forward'
+            self.hstyle = value
+        elif value == 'manyone':
+            self.dir = 'back'
+            self.hstyle = value
+        elif value == 'manymany':
+            self.dir = 'both'
+            self.hstyle = value
         else:
             msg = "WARNING: unknown edge hstyle: %s\n" % value
             raise AttributeError(msg)
@@ -530,6 +555,10 @@ class DiagramEdge(Base):
 
         return dir
 
+    def to_desctable(self):
+        label = "%s -> %s" % (self.node1.label, self.node2.label)
+        return [label, self.description]
+
 
 class Diagram(NodeGroup):
     _DiagramNode = DiagramNode
@@ -571,10 +600,9 @@ class Diagram(NodeGroup):
         plugins.load(modules, diagram=self)
 
     def set_default_shape(self, value):
-        try:
-            noderenderer.get(value)
+        if noderenderer.get(value):
             DiagramNode.set_default_shape(value)
-        except:
+        else:
             msg = "WARNING: unknown node shape: %s\n" % value
             raise AttributeError(msg)
 
