@@ -530,20 +530,9 @@ class LandscapeEdgeMetrics(EdgeMetrics):
                     heads.append('left')
                 else:
                     heads.append('up')
-        elif self.edge.dir in ('manyone', 'manymany'):
-            if dir in ('left-up', 'left', 'same',
-                       'right-up', 'right', 'right-down'):
-                heads.append('rleft')
-            elif dir == 'up':
-                if self.edge.skipped:
-                    heads.append('rleft')
-                else:
-                    heads.append('rdown')
-            elif dir in ('left-down', 'down'):
-                if self.edge.skipped:
-                    heads.append('rleft')
-                else:
-                    heads.append('rup')
+
+            if self.edge.hstyle in ('manyone', 'manymany'):
+                heads[-1] = 'r' + heads[-1]
         else:
             heads.append(None)
 
@@ -554,13 +543,9 @@ class LandscapeEdgeMetrics(EdgeMetrics):
                 heads.append('up')
             elif dir in ('left-up', 'left', 'left-down', 'down', 'same'):
                 heads.append('down')
-        elif self.edge.dir in ('onemany', 'manymany'):
-            if dir in ('right-up', 'right', 'right-down'):
-                heads.append('rright')
-            elif dir == 'up':
-                heads.append('rup')
-            elif dir in ('left-up', 'left', 'left-down', 'down', 'same'):
-                heads.append('rdown')
+
+            if self.edge.hstyle in ('onemany', 'manymany'):
+                heads[-1] = 'r' + heads[-1]
         else:
             heads.append(None)
 
@@ -745,6 +730,9 @@ class PortraitEdgeMetrics(EdgeMetrics):
                     heads.append('left')
                 else:
                     heads.append('up')
+
+            if self.edge.hstyle in ('manyone', 'manymany'):
+                heads[-1] = 'r' + heads[-1]
         else:
             heads.append(None)
 
@@ -758,6 +746,9 @@ class PortraitEdgeMetrics(EdgeMetrics):
                 heads.append('down')
             elif dir in ('left-up', 'left', 'left-down', 'down', 'right-down'):
                 heads.append('down')
+
+            if self.edge.hstyle in ('onemany', 'manymany'):
+                heads[-1] = 'r' + heads[-1]
         else:
             heads.append(None)
 
@@ -905,12 +896,18 @@ class FlowchartLandscapeEdgeMetrics(LandscapeEdgeMetrics):
 
         if self.edge.direction == 'right-down':
             if self.edge.dir in ('back', 'both'):
-                heads.append('up')
+                if self.edge.hstyle in ('manyone', 'manymany'):
+                    heads.append('rup')
+                else:
+                    heads.append('up')
             else:
                 heads.append(None)
 
             if self.edge.dir in ('forward', 'both'):
-                heads.append('right')
+                if self.edge.hstyle in ('onemany', 'manymany'):
+                    heads.append('rright')
+                else:
+                    heads.append('right')
             else:
                 heads.append(None)
         else:
@@ -974,12 +971,18 @@ class FlowchartPortraitEdgeMetrics(PortraitEdgeMetrics):
 
         if self.edge.direction == 'right-down':
             if self.edge.dir in ('back', 'both'):
-                heads.append('left')
+                if self.edge.hstyle in ('manyone', 'manymany'):
+                    heads.append('left')
+                else:
+                    heads.append('left')
             else:
                 heads.append(None)
 
             if self.edge.dir in ('forward', 'both'):
-                heads.append('down')
+                if self.edge.dir in ('onemany', 'manymany'):
+                    heads.append('rdown')
+                else:
+                    heads.append('down')
             else:
                 heads.append(None)
         else:
